==> jc-1.4.0.tar.gz: scm/Selfrep.h <==
// class scm.Selfrep

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 50b36d90e0eacd15 scm_Selfrep

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_Selfrep_H_
#define _JC_scm_Selfrep_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_Selfrep$sub_refs	_jc_scm_Selfrep$sub_refs;
typedef struct _jc_scm_Selfrep$sub_nonrefs	_jc_scm_Selfrep$sub_nonrefs;
typedef struct _jc_scm_Selfrep$refs	_jc_scm_Selfrep$refs;
typedef struct _jc_scm_Selfrep$nonrefs	_jc_scm_Selfrep$nonrefs;
typedef struct _jc_scm_Selfrep$object	_jc_scm_Selfrep$object;

typedef const struct _jc_scm_Selfrep$vmethods	_jc_scm_Selfrep$vmethods;
typedef const struct _jc_scm_Selfrep$vtable	_jc_scm_Selfrep$vtable;
typedef const struct _jc_scm_Selfrep$vtype	_jc_scm_Selfrep$vtype;

// Constructors
extern void _jc_scm_Selfrep$method$_init$150bab920ca55717(_jc_env *, struct _jc_scm_Selfrep$object *, jdouble);
extern void _jc_scm_Selfrep$method$_init$c31b894660454d13(_jc_env *, struct _jc_scm_Selfrep$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_Selfrep$method$eval$45e01bedb73fc9c4(_jc_env *, struct _jc_scm_Selfrep$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_Selfrep$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Selfrep$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_Selfrep$method_info$eval$45e01bedb73fc9c4;
extern _jc_method _jc_scm_Selfrep$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_Selfrep$vmethods {
	struct _jc_object	*(*eval$45e01bedb73fc9c4)(_jc_env *, struct _jc_scm_Selfrep$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Selfrep$object *);
};

// Vtable
struct _jc_scm_Selfrep$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Selfrep$vmethods	scm_Selfrep;
};

// Vtype
struct _jc_scm_Selfrep$vtype {
	_jc_type			type;
	_jc_scm_Selfrep$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Selfrep$sub_refs {
	struct _jc_java_lang_String$object	*val;
};

// Reference instance fields (object)
struct _jc_scm_Selfrep$refs {
    _jc_scm_Selfrep$sub_refs	scm_Selfrep;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Selfrep$sub_nonrefs {
	jdouble	num;
};

// Non-reference instance fields (object)
struct _jc_scm_Selfrep$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Selfrep$sub_nonrefs	scm_Selfrep;
};

// Object instance structure
struct _jc_scm_Selfrep$object {
	_jc_scm_Selfrep$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Selfrep$vtype	*vtype;
	_jc_scm_Selfrep$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Selfrep$vtype _jc_scm_Selfrep$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Selfrep, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Selfrep$class_object;

#endif	/* _JC_scm_Selfrep_H_ */

==> jc-1.4.6.tar.gz: scm/Selfrep.h <==
// class scm.Selfrep

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 50b36d90e0eacd15 scm_Selfrep

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_Selfrep_H_
#define _JC_scm_Selfrep_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_Selfrep$sub_refs	_jc_scm_Selfrep$sub_refs;
typedef struct _jc_scm_Selfrep$sub_nonrefs	_jc_scm_Selfrep$sub_nonrefs;
typedef struct _jc_scm_Selfrep$refs	_jc_scm_Selfrep$refs;
typedef struct _jc_scm_Selfrep$nonrefs	_jc_scm_Selfrep$nonrefs;
typedef struct _jc_scm_Selfrep$object	_jc_scm_Selfrep$object;

typedef const struct _jc_scm_Selfrep$vmethods	_jc_scm_Selfrep$vmethods;
typedef const struct _jc_scm_Selfrep$vtable	_jc_scm_Selfrep$vtable;
typedef const struct _jc_scm_Selfrep$vtype	_jc_scm_Selfrep$vtype;

// Constructors
extern void _jc_scm_Selfrep$method$_init$150bab920ca55717(_jc_env *, struct _jc_scm_Selfrep$object *, jdouble) _JC_JCNI_ATTR;
extern void _jc_scm_Selfrep$method$_init$c31b894660454d13(_jc_env *, struct _jc_scm_Selfrep$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_Selfrep$method$eval$45e01bedb73fc9c4(_jc_env *, struct _jc_scm_Selfrep$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_Selfrep$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Selfrep$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_Selfrep$method_info$eval$45e01bedb73fc9c4;
extern _jc_method _jc_scm_Selfrep$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_Selfrep$vmethods {
	struct _jc_object	*(*eval$45e01bedb73fc9c4)(_jc_env *, struct _jc_scm_Selfrep$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Selfrep$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_Selfrep$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Selfrep$vmethods	scm_Selfrep;
};

// Vtype
struct _jc_scm_Selfrep$vtype {
	_jc_type			type;
	_jc_scm_Selfrep$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Selfrep$sub_refs {
	struct _jc_java_lang_String$object	*val;
};

// Reference instance fields (object)
struct _jc_scm_Selfrep$refs {
    _jc_scm_Selfrep$sub_refs	scm_Selfrep;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Selfrep$sub_nonrefs {
	jdouble	num;
};

// Non-reference instance fields (object)
struct _jc_scm_Selfrep$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Selfrep$sub_nonrefs	scm_Selfrep;
};

// Object instance structure
struct _jc_scm_Selfrep$object {
	_jc_scm_Selfrep$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Selfrep$vtype	*vtype;
	_jc_scm_Selfrep$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Selfrep$vtype _jc_scm_Selfrep$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Selfrep, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Selfrep$class_object;

#endif	/* _JC_scm_Selfrep_H_ */
